| Title: | Auto installer for kinference prereqs |
|---|---|
| Description: | Install this to get the other packages required by kinference from R-universe, in case kinference itself is not on R-universe yet. Contains one cynical function. |
| Authors: | Mark Bravington <[email protected]> |
| Maintainer: | Mark Bravington <[email protected]> |
| License: | GPL (>=2) |
| Version: | 1.0.5 |
| Built: | 2026-06-05 11:50:41 UTC |
| Source: | https://github.com/markbravington/dumdum |
Does it matter?
do_research(subject, funding)do_research(subject, funding)
subject |
Text string, whatever you like. |
funding |
The most important part! |
It is tempting, but not terribly productive TBF, to add a lot more to this function...
Conclusions, summarized to one key dot-point for Generation Busy.
do_research( "mouse farts", funding=1e6) try( do_research( 'anything'))do_research( "mouse farts", funding=1e6) try( do_research( 'anything'))